{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "id": "#bgzip.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index.cwl/indexed_vcf"
                }
            ],
            "id": "#index.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HaplotypeCaller (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "-gt_mode",
                "GENOTYPE_GIVEN_ALLELES",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/docm_out.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--alleles",
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 5
                    },
                    "id": "#GATK_haplotype_caller.cwl/interval_list"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#GATK_haplotype_caller.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_out.vcf"
                    },
                    "id": "#GATK_haplotype_caller.cwl/docm_out"
                }
            ],
            "id": "#GATK_haplotype_caller.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "docm filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/docm_filter.pl",
                "$(inputs.docm_out.path)",
                "$(inputs.normal_cram.path)",
                "$(inputs.tumor_cram.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#docm_filter.cwl/docm_out"
                },
                {
                    "type": "File",
                    "id": "#docm_filter.cwl/normal_cram"
                },
                {
                    "type": "File",
                    "id": "#docm_filter.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_filter_out.vcf"
                    },
                    "id": "#docm_filter.cwl/docm_filter_out"
                }
            ],
            "id": "#docm_filter.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect Docm variants",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/GATK_haplotype_caller/docm_out",
                    "id": "#main/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#GATK_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#main/docm_vcf",
                            "id": "#main/GATK_haplotype_caller/docm_vcf"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/GATK_haplotype_caller/interval_list"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/GATK_haplotype_caller/normal_cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/GATK_haplotype_caller/reference"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/GATK_haplotype_caller/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/GATK_haplotype_caller/docm_out"
                    ],
                    "id": "#main/GATK_haplotype_caller"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/docm_filter/docm_filter_out",
                            "id": "#main/bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip/bgzipped_file"
                    ],
                    "id": "#main/bgzip"
                },
                {
                    "run": "#docm_filter.cwl",
                    "in": [
                        {
                            "source": "#main/GATK_haplotype_caller/docm_out",
                            "id": "#main/docm_filter/docm_out"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/docm_filter/normal_cram"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/docm_filter/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/docm_filter/docm_filter_out"
                    ],
                    "id": "#main/docm_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip/bgzipped_file",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
